<?php
/**
 * @file
 * Contains \Drupal\static_page\Form\StaticPageSettingsForm.
 */

namespace Drupal\static_page\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\node\Entity\NodeType;

/**
 * Configure search settings for this site.
 */
class StaticPageSettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'static_page_config_form';
  }
  
  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['static_page.types'];
  }
  
  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('static_page.types');
    $types = NodeType::loadMultiple();
    $options = array();
    foreach ($types as $key => $value) {
      $options[$key] = $value->label();
    }
	
    $form['types'] = array(
      '#title' => t('Content types used as static page'),
      '#type' =>'checkboxes',
      '#description' =>t('All nodes of these selected types will be used as static page.'),
      '#options' => $options,
	  '#default_value' => $config->get('types')
    );

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config('static_page.types')
      ->set('types', array_filter($form_state->getValue('types')))
      ->save();	 

    parent::submitForm($form, $form_state);
  }

}
